#!/usr/bin/env python3
# coding=UTF-8
#
# Copyright 2022. quinn.7@foxmail.com All rights reserved.
# Author :: cat7
# Email  :: quinn.7@foxmail.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, 
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# =============================================================================
"""
[ 类型常量 ]

"""


# ----------------------------------
class ConstType(object):
    """ [ 类型常量 ] """

    PROJECT_TYPE_WEB: str = 'WEB'
    """ [ WEB项目 ] """

    PROJECT_TYPE_API: str = 'API'
    """ [ API项目 ] """

    TASK_EXECUTION_MODE_CODE: str = 'CODE'
    """ [ 任务执行模式::代码 ] """

    TASK_EXECUTION_MODE_JSON: str = 'JSON'
    """ [ 任务执行模式::JSON ] """
